==> qmltube_0.2.16.tar.gz: qmltube-0.2.16/qml/qmltube/mainscripts.js <==
/* Main view functions */

function restoreSettings() {
    /* Restore the user's settings from the database */

    Settings.initialize();
    Controller.setOrientation(Settings.getSetting("screenOrientation"));
    Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
    YouTube.setPlaybackQuality(Settings.getSetting("playbackQuality"));
    DownloadManager.setDownloadQuality(Settings.getSetting("downloadQuality"));
    signInToDefaultAccount();
    getArchiveVideos();
    Settings.restoreDownloads();
}

function getArchiveVideos() {
    /* Retrieve archive videos and populate the list model */

    var videos = Settings.getAllArchiveVideos();
    for (var i = 0; i < videos.length ; i++) {
        archiveModel.insert(0, { "filePath": videos[i][0], "title": videos[i][1],
                            "thumbnail": videos[i][2], "quality": videos[i][3],
                            "isNew": videos[i][4] });
    }
}

function moveToArchive(video) {
    Settings.addVideoToArchive(video);
    archiveModel.insert(0, video);
}

function signInToDefaultAccount() {
    var defaultAccount = Settings.getDefaultAccount();
    if (defaultAccount != "unknown") {
        var username = defaultAccount[0];
        var password = defaultAccount[1];
        toggleBusy(true);
        YouTube.login(username, password);
    }
    else if (Settings.getSetting("noAccountDialog") != "raised") {
        homeView.showNoAccountDialog();
    }
}

function goHome() {
    windowView.currentIndex = 0;
    notificationArea.titleList = ["cuteTube"];
    for (var i = 1; i < viewsModel.children.length; i++) {
        viewsModel.children[i].source = "";
    }
}

function goToPreviousView() {
    var i = windowView.currentIndex;
    windowView.decrementCurrentIndex();
    viewsModel.children[i].source = "";
    notificationArea.removeTitle();
    toggleBusy(false);
}

function loadAccountView() {

    if (userIsSignedIn()) {
        var loader = viewsModel.children[windowView.currentIndex + 1];
        windowView.currentItem.visible = false;
        loader.source = "MyAccountView.qml";
        loader.item.uploads.connect(loadVideos);
        loader.item.favourites.connect(loadVideos);
        loader.item.playlists.connect(loadPlaylists);
        loader.item.subscriptions.connect(loadSubscriptions);
        notificationArea.addTitle("My Channel");
        windowView.incrementCurrentIndex();
    }
    else {
        displayMessage("No YouTube account found")
    }
}

function loadArchiveView() {
    /* Loads the view of previously downloaded videos */

    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "ArchiveListView.qml";
    notificationArea.addTitle("Archive");
    windowView.incrementCurrentIndex();
}

function loadVideos(feed, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "VideoListView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadUserVideos(username) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "UserVideosView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.getUserProfile(username);
    notificationArea.addTitle(username);
    windowView.incrementCurrentIndex();
}

function loadPlaylistVideos(playlistId, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "PlaylistVideosView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.setVideoFeed("http://gdata.youtube.com/feeds/api/playlists/" + playlistId + "?v=2&max-results=50");
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadPlaylists() {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "PlaylistsView.qml";
    loader.item.goToPlaylist.connect(loadPlaylistVideos);
    notificationArea.addTitle("My Playlists");
    windowView.incrementCurrentIndex();
}

function loadSubscriptions() {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "SubscriptionsView.qml";
    loader.item.goToUserVideos.connect(loadUserVideos);
    loader.item.goToNewSubVideos.connect(loadVideos);
    notificationArea.addTitle("My Subscriptions");
    windowView.incrementCurrentIndex();
}

function loadVideoInfo(video) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "VideoInfoView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.authorClicked.connect(loadUserVideos);
    loader.item.search.connect(search);
    loader.item.setVideo(video);
    notificationArea.addTitle("Video Info");
    windowView.incrementCurrentIndex();
}

function loadDownloads() {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "DownloadListView.qml";
    notificationArea.addTitle("Downloads");
    windowView.incrementCurrentIndex();
}

function search(query) {
    /* Perform a YouTube search and open video list window */

    var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
                     + query.replace(" ", "+"));
    loadVideos(videoFeed, "Search ('" + query + "')");
}

function toggleMenu() {
    /* Show/hide the menu of the current view */

    if (windowView.currentIndex == 0) {
        windowView.currentItem.toggleMenu();
    }
    else {
        windowView.currentItem.item.toggleMenu();
    }
}

function toggleControls(showOrHide) {
    /* Show/hide the notification area and menu bar */

    notificationArea.visible = showOrHide;
    menuBar.visible = showOrHide;
}

==> qmltube_0.2.20.tar.gz: qmltube-0.2.20/qml/qmltube/mainscripts.js <==
/* Main view functions */

function restoreSettings() {
    /* Restore the user's settings from the database */

    Settings.initialize();
    Controller.setOrientation(Settings.getSetting("screenOrientation"));
    if (Controller.kmPlayerInstalled()) {
        Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
    }
    else {
        Settings.setSetting("mediaPlayer", "Media Player");
        Controller.setMediaPlayer("Media Player");
    }
    YouTube.setPlaybackQuality(Settings.getSetting("playbackQuality"));
    DownloadManager.setDownloadQuality(Settings.getSetting("downloadQuality"));
    signInToDefaultAccount();
    getArchiveVideos();
    Settings.restoreDownloads();
}

function getArchiveVideos() {
    /* Retrieve archive videos and populate the list model */

    var videos = Settings.getAllArchiveVideos();
    for (var i = 0; i < videos.length ; i++) {
        archiveModel.insert(0, { "filePath": videos[i][0], "title": videos[i][1],
                            "thumbnail": videos[i][2], "quality": videos[i][3],
                            "isNew": videos[i][4] });
    }
}

function moveToArchive(video) {
    Settings.addVideoToArchive(video);
    archiveModel.insert(0, video);
}

function signInToDefaultAccount() {
    var defaultAccount = Settings.getDefaultAccount();
    if (defaultAccount != "unknown") {
        var username = defaultAccount[0];
        var password = defaultAccount[1];
        toggleBusy(true);
        YouTube.login(username, password);
    }
    else if (Settings.getSetting("noAccountDialog") != "raised") {
        homeView.showNoAccountDialog();
    }
}

function goHome() {
    windowView.currentIndex = 0;
    notificationArea.titleList = ["cuteTube"];
    for (var i = 1; i < viewsModel.children.length; i++) {
        viewsModel.children[i].source = "";
    }
}

function goToPreviousView() {
    var i = windowView.currentIndex;
    windowView.decrementCurrentIndex();
    viewsModel.children[i].source = "";
    notificationArea.removeTitle();
    toggleBusy(false);
}

function loadAccountView() {

    if (userIsSignedIn()) {
        var loader = viewsModel.children[windowView.currentIndex + 1];
        windowView.currentItem.visible = false;
        loader.source = "MyAccountView.qml";
        loader.item.uploads.connect(loadVideos);
        loader.item.favourites.connect(loadVideos);
        loader.item.playlists.connect(loadPlaylists);
        loader.item.subscriptions.connect(loadSubscriptions);
        notificationArea.addTitle("My Channel");
        windowView.incrementCurrentIndex();
    }
    else {
        displayMessage("No YouTube account found")
    }
}

function loadArchiveView() {
    /* Loads the view of previously downloaded videos */

    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "ArchiveListView.qml";
    notificationArea.addTitle("Archive");
    windowView.incrementCurrentIndex();
}

function loadVideos(feed, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "VideoListView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.setVideoFeed(feed);
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadUserVideos(username) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "UserVideosView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.getUserProfile(username);
    notificationArea.addTitle(username);
    windowView.incrementCurrentIndex();
}

function loadPlaylistVideos(playlistId, title) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "PlaylistVideosView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.setVideoFeed("http://gdata.youtube.com/feeds/api/playlists/" + playlistId + "?v=2&max-results=50");
    notificationArea.addTitle(title);
    windowView.incrementCurrentIndex();
}

function loadPlaylists() {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "PlaylistsView.qml";
    loader.item.goToPlaylist.connect(loadPlaylistVideos);
    notificationArea.addTitle("My Playlists");
    windowView.incrementCurrentIndex();
}

function loadSubscriptions() {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "SubscriptionsView.qml";
    loader.item.goToUserVideos.connect(loadUserVideos);
    loader.item.goToNewSubVideos.connect(loadVideos);
    notificationArea.addTitle("My Subscriptions");
    windowView.incrementCurrentIndex();
}

function loadVideoInfo(video) {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "VideoInfoView.qml";
    loader.item.goToVideo.connect(loadVideoInfo);
    loader.item.authorClicked.connect(loadUserVideos);
    loader.item.search.connect(search);
    loader.item.setVideo(video);
    notificationArea.addTitle("Video Info");
    windowView.incrementCurrentIndex();
}

function loadDownloads() {
    var loader = viewsModel.children[windowView.currentIndex + 1];
    windowView.currentItem.visible = false;
    loader.source = "DownloadListView.qml";
    notificationArea.addTitle("Downloads");
    windowView.incrementCurrentIndex();
}

function search(query) {
    /* Perform a YouTube search and open video list window */

    var videoFeed = ("http://gdata.youtube.com/feeds/api/videos?v=2&max-results=50&safeSearch=none&q="
                     + query.replace(" ", "+"));
    loadVideos(videoFeed, "Search ('" + query + "')");
}

function toggleMenu() {
    /* Show/hide the menu of the current view */

    if (windowView.currentIndex == 0) {
        windowView.currentItem.toggleMenu();
    }
    else {
        windowView.currentItem.item.toggleMenu();
    }
}

function toggleControls(showOrHide) {
    /* Show/hide the notification area and menu bar */

    notificationArea.visible = showOrHide;
    menuBar.visible = showOrHide;
}
